==> nextcloud-app-calendar-1%3A2.3.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/mn.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s хэрэглэгч »%s« календарийг нийтлэв",
    "Hello," : "Сайн байна уу",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s хэрэглэгч нь  »%s« календарийг нийтэлснийг үүгээр мэдэгдэе.",
    "Open »%s«" : "»%s« нээх",
    "Cheers!" : "Болж байна!",
    "Calendar" : "Календарь",
    "Today" : "Өнөөдөр",
    "Day" : "Өдөр",
    "Week" : "Долоо хоног",
    "Month" : "Сар",
    "Download" : "Татаж авах",
    "Delete" : "Устгах",
    "Share link" : "Холбоос хуваалцах",
    "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
    "can edit" : "засаж чадна",
    "New calendar" : "Шинэ цагийн хуваарь",
    "Filename" : "Файлын нэр",
    "Cancel" : "Цуцлах",
    "Actions" : "Үйл ажиллагаа",
    "Show week numbers" : "7 хоногийн дугаарыг харуулах",
    "Settings & import" : "Тохиргоо, импорт",
    "Notification" : "Мэдэгдэл",
    "Email" : "Цахим шуудан",
    "Unknown" : "Үл танигдах зүйл",
    "never" : "хэзээ ч үгүй",
    "after" : "дараа",
    "Repeat" : "Давтах",
    "Monday" : "даваа",
    "Summary" : "Хураангуй",
    "More" : "Дэлгэрэнгүй",
    "Save" : "Хадгалах",
    "Update" : "Шинэчлэх",
    "Personal" : "Хувийн",
    "Details" : "Дэлгэрэнгүй",
    "Attendees" : "Оролцогчид",
    "Reminders" : "Сануулагууд",
    "Close" : "Хаах",
    "Week {number} of {year}" : "{year} оны {number}-р долоо хоног ",
    "Daily" : "Өдөр бүр",
    "Weekly" : "Долоо хоног бүр",
    "When shared show full event" : "Түгээсэн тохиолдолд үйл явдлыг бүтнээр нь харуул",
    "When shared show only busy" : "Түгээсэн тохиолдолд зөвхөн завгүй гэж харуул",
    "When shared hide this event" : "Түгээсэн тохиолдолд энэ үйл явдлыг нуу",
    "Location" : "Байршил",
    "Description" : "Тодорхойлолт",
    "Status" : "төлөв",
    "Confirmed" : "Баталгаажсан",
    "Tentative" : "Урьдчилсан тов",
    "Categories" : "төрөл",
    "Mail" : "Цахим шуудан",
    "Global" : "Нийтийн"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A3.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/mn.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s хэрэглэгч »%s« календарийг нийтлэв",
    "Hello," : "Сайн байна уу",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s хэрэглэгч нь  »%s« календарийг нийтэлснийг үүгээр мэдэгдэе.",
    "Open »%s«" : "»%s« нээх",
    "Cheers!" : "Болж байна!",
    "Calendar" : "Календарь",
    "Today" : "Өнөөдөр",
    "Day" : "Өдөр",
    "Week" : "Долоо хоног",
    "Month" : "Сар",
    "Delete" : "Устгах",
    "Download" : "Татаж авах",
    "Share link" : "Холбоос хуваалцах",
    "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
    "can edit" : "засаж чадна",
    "New calendar" : "Шинэ цагийн хуваарь",
    "Filename" : "Файлын нэр",
    "Cancel" : "Цуцлах",
    "Actions" : "Үйл ажиллагаа",
    "Show week numbers" : "7 хоногийн дугаарыг харуулах",
    "Settings & import" : "Тохиргоо, импорт",
    "Location" : "Байршил",
    "Description" : "Тодорхойлолт",
    "Monday" : "даваа",
    "Save" : "Хадгалах",
    "Update" : "Шинэчлэх",
    "Notification" : "Мэдэгдэл",
    "Email" : "Цахим шуудан",
    "Unknown" : "Үл танигдах зүйл",
    "Repeat" : "Давтах",
    "never" : "хэзээ ч үгүй",
    "after" : "дараа",
    "More" : "Дэлгэрэнгүй",
    "Global" : "Нийтийн",
    "Personal" : "Хувийн",
    "Details" : "Дэлгэрэнгүй",
    "Attendees" : "Оролцогчид",
    "Close" : "Хаах",
    "Week {number} of {year}" : "{year} оны {number}-р долоо хоног ",
    "Daily" : "Өдөр бүр",
    "Weekly" : "Долоо хоног бүр",
    "When shared show full event" : "Түгээсэн тохиолдолд үйл явдлыг бүтнээр нь харуул",
    "When shared show only busy" : "Түгээсэн тохиолдолд зөвхөн завгүй гэж харуул",
    "When shared hide this event" : "Түгээсэн тохиолдолд энэ үйл явдлыг нуу",
    "Status" : "төлөв",
    "Confirmed" : "Баталгаажсан",
    "Tentative" : "Урьдчилсан тов",
    "Categories" : "төрөл",
    "Mail" : "Цахим шуудан"
},
"nplurals=2; plural=(n != 1);");
